==> haskell-managed-1.0.10-2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-managed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 managed
version:              1.0.10
visibility:           public
id:                   managed-1.0.10-L0mohGNFmrILG4eO9HBKee
key:                  managed-1.0.10-L0mohGNFmrILG4eO9HBKee
license:              BSD-3-Clause
copyright:            2014 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             A monad for managed values
description:
    In Haskell you very often acquire values using the @with...@
    idiom using functions of type @(a -> IO r) -> IO r@.  This idiom forms a
    @Monad@, which is a special case of the @ContT@ monad (from @transformers@) or
    the @Codensity@ monad (from @kan-extensions@).  The main purpose behind this
    package is to provide a restricted form of these monads specialized to this
    unusually common case.

    The reason this package defines a specialized version of these types is to:

    * be more beginner-friendly,

    * simplify inferred types and error messages, and:

    * provide some additional type class instances that would otherwise be orphan
    instances

category:             Control
abi:                  664b762146ac7a31c712f02424c9ecdb
exposed:              True
exposed-modules:      Control.Monad.Managed Control.Monad.Managed.Safe
import-dirs:          /usr/lib/ghc-9.2.8/site-local/managed-1.0.10
library-dirs:         /usr/lib/ghc-9.2.8/site-local/managed-1.0.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-managed
hs-libraries:         HSmanaged-1.0.10-L0mohGNFmrILG4eO9HBKee
depends:              base-4.16.4.0 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-managed/html/managed.haddock
haddock-html:         /usr/share/doc/haskell-managed/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-managed-1.0.10-3-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-managed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 managed
version:              1.0.10
visibility:           public
id:                   managed-1.0.10-CrvLNY2sLDT8jZhIlothny
key:                  managed-1.0.10-CrvLNY2sLDT8jZhIlothny
license:              BSD-3-Clause
copyright:            2014 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             A monad for managed values
description:
    In Haskell you very often acquire values using the @with...@
    idiom using functions of type @(a -> IO r) -> IO r@.  This idiom forms a
    @Monad@, which is a special case of the @ContT@ monad (from @transformers@) or
    the @Codensity@ monad (from @kan-extensions@).  The main purpose behind this
    package is to provide a restricted form of these monads specialized to this
    unusually common case.

    The reason this package defines a specialized version of these types is to:

    * be more beginner-friendly,

    * simplify inferred types and error messages, and:

    * provide some additional type class instances that would otherwise be orphan
    instances

category:             Control
abi:                  00ba4e11a81ae0d5c0d5e6f8c0f4d867
exposed:              True
exposed-modules:      Control.Monad.Managed Control.Monad.Managed.Safe
import-dirs:          /usr/lib/ghc-9.4.8/site-local/managed-1.0.10
library-dirs:         /usr/lib/ghc-9.4.8/site-local/managed-1.0.10
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/managed-1.0.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-managed
hs-libraries:         HSmanaged-1.0.10-CrvLNY2sLDT8jZhIlothny
depends:              base-4.17.2.1 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-managed/html/managed.haddock
haddock-html:         /usr/share/doc/haskell-managed/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
